==> magic3_1.6.8_src.tar.gz: magic3/widgets/admin_main/include/help/index.php <==
<?php
/**
 * ヘルプリソースファイル
 * index.php
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2008 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: index.php 1020 2008-09-18 04:54:56Z fishbone $
 * @link       http://www.magic3.org
 */
// 直接アクセスの防止
defined('M3_SYSTEM') or die('Access error: Direct access denied.');

global $HELP;

// ########## ユーザ一覧 ##########
$HELP['userlist']['title'] = 'ユーザ一覧';
$HELP['userlist']['body'] = 'システムで一元管理するユーザの一覧です。';
$HELP['userlist_check']['title'] = '選択用チェックボックス';
$HELP['userlist_check']['body'] = '編集や削除を行う項目を選択します。';
$HELP['userlist_account']['title'] = 'ユーザアカウント';
$HELP['userlist_account']['body'] = 'ログイン時に使用するアカウントです。<br>メールアドレス形式のアカウントも使用できます。';
$HELP['userlist_pwd']['title'] = 'ユーザパスワード';
$HELP['userlist_pwd']['body'] = 'ログイン時に使用するパスワードです。';
$HELP['userlist_name']['title'] = '名前';
$HELP['userlist_name']['body'] = '画面上に表示されるユーザの名前です。';
$HELP['userlist_usertype']['title'] = 'ユーザ種別';
$HELP['userlist_usertype']['body'] = '管理者 - 管理機能にログインできます。<br>一般 - 管理機能以外の機能にログインできます。<br>仮登録 - 一般機能からユーザ登録を行い、まだログインしていないユーザです。一度ログインすると一般ユーザに変更されます。';
$HELP['userlist_admin']['title'] = '管理権限';
$HELP['userlist_admin']['body'] = '管理画面にアクセス可能かどうかの設定です。<br>チェックが入っているとアクセス可能です。';
$HELP['userlist_login']['title'] = 'ログイン可';
$HELP['userlist_login']['body'] = 'ログインを許可するかどうかの設定です。<br>チェックが入っているとログイン可能です。';
$HELP['userlist_new_btn']['title'] = '新規ボタン';
$HELP['userlist_new_btn']['body'] = '新規ユーザを追加します。';
$HELP['userlist_edit_btn']['title'] = '編集ボタン';
$HELP['userlist_edit_btn']['body'] = '選択されているユーザを編集します。<br>ユーザを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['userlist_del_btn']['title'] = '削除ボタン';
$HELP['userlist_del_btn']['body'] = '選択されているユーザを削除します。<br>ユーザを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['userlist_ret_btn']['title'] = '戻るボタン';
$HELP['userlist_ret_btn']['body'] = 'ユーザ一覧へ戻ります。';

// ########## 画面作成 ##########
$HELP['pagedef_page_id']['title'] = 'ページID';
$HELP['pagedef_page_id']['body'] = 'ページを定義するためのIDです。IDはURLに付加されます。非公開項目は管理権限のない一般ユーザには公開されないページです。';
$HELP['pagedef_page_sub_id']['title'] = 'ページサブID';
$HELP['pagedef_page_sub_id']['body'] = 'ページを定義するための補助IDです。IDはURLに付加されます。';
$HELP['pagedef_preview_url']['title'] = 'URL';
$HELP['pagedef_preview_url']['body'] = 'プレビューに表示しているページへのURLです。';
$HELP['pagedef_detail_btn']['title'] = '詳細ボタン';
$HELP['pagedef_detail_btn']['body'] = 'ページ定義の詳細を表示します。';
$HELP['pagedef_default_template']['title'] = 'デフォルトテンプレート';
$HELP['pagedef_default_template']['body'] = 'デフォルトで設定されるデザインテンプレートを指定します。';
$HELP['pagedef_change_template_btn']['title'] = 'テンプレート変更';
$HELP['pagedef_change_template_btn']['body'] = 'デフォルトのテンプレートを変更します。';
$HELP['pagedef_template_img']['title'] = 'テンプレート表示イメージ';
$HELP['pagedef_template_img']['body'] = 'テンプレートを設定した場合の画面の表示イメージです。';
$HELP['pagedef_widget']['title'] = 'ウィジェット';
$HELP['pagedef_widget']['body'] = 'レイアウトに配置可能なウィジェットです。シングルクリックで取得し、画面レイアウト領域に配置します。';
$HELP['pagedef_layout']['title'] = '画面レイアウト';
$HELP['pagedef_layout']['body'] = '(ウィジェットの配置)<br>テンプレートにウィジェットを配置し、画面を作成します。ウィジェット一覧からマウスドラッグでウィジェットを取り出します。レイアウト画面の任意のポジション位置にドロップするとウィジェットが配置できます。レイアウト画面からウィジェットを削除するには、削除するウィジェットの右上のクローズボックスをクリックします。一度ドロップしたウィジェットは、ドラッグドロップでページ上の移動が可能です。最大化ボタンまたはESCキーでレイアウト画面が最大化できます。最大化状態から元に戻るにはESCキーを押します。<br>(ウィジェットコンテキストメニュー)<br>ウィジェットをマウス右クリックするとコンテキストメニューが表示されます。ウィジェットの設定を行ったり、ウィジェットの削除を行います。「ページ共通」属性を設定したウィジェットは、ページに関わらず常に表示されます。(赤色表示)';
$HELP['pagedef_preview']['title'] = 'レイアウトとプレビューの切り替えボタン';
$HELP['pagedef_preview']['body'] = 'ウィジェットの配置を行うレイアウト画面と、実際に表示されるプレビュー画面を切り替えます。';
$HELP['pagedef_refresh']['title'] = '画面再表示';
$HELP['pagedef_refresh']['body'] = 'レイアウトまたはプレビュー画面を再表示します。';
$HELP['pagedef_preview_other']['title'] = '別画面でプレビュー';
$HELP['pagedef_preview_other']['body'] = '実際に表示される画面を別ウィンドウで表示します。';
$HELP['pagedef_position_block']['title'] = 'ポジションブロック名';
$HELP['pagedef_position_block']['body'] = 'デザインテンプレート内でのウィジェットの配置ブロックを指定します。';
$HELP['pagedef_position_index']['title'] = '表示順';
$HELP['pagedef_position_index']['body'] = 'ポジションブロック内でのウィジェットの表示順を指定します。';
$HELP['pagedef_widget_def_id']['title'] = '定義ID';
$HELP['pagedef_widget_def_id']['body'] = '個別のウィジェットの設定IDです。設定が必要な場合のみ設定可能になります。';
$HELP['pagedef_widget_visible']['title'] = 'ウィジェット表示制御';
$HELP['pagedef_widget_visible']['body'] = 'ウィジェットの表示、非表示を制御します。';
$HELP['pagedef_widget_common']['title'] = 'ページ共通属性';
$HELP['pagedef_widget_common']['body'] = '同ページIDで、サブページIDに関わらずウィジェットを表示するかどうかを指定します。';

// ########## テーブルデータ編集 ##########
$HELP['edittable_new_btn']['title'] = '新規ボタン';
$HELP['edittable_new_btn']['body'] = '新規レコードを追加します。';
$HELP['edittable_edit_btn']['title'] = '編集ボタン';
$HELP['edittable_edit_btn']['body'] = '選択されているレコードを編集します。<br>レコードを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['edittable_del_btn']['title'] = '削除ボタン';
$HELP['edittable_del_btn']['body'] = '選択されているレコードを削除します。<br>レコードを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['edittable_ret_btn']['title'] = '戻るボタン';
$HELP['edittable_ret_btn']['body'] = 'レコード一覧へ戻ります。';

// ########## 管理メニュー編集編集 ##########
$HELP['editmenu_config_others_btn']['title'] = 'その他ボタン';
$HELP['editmenu_config_others_btn']['body'] = 'その他の設定を行います。';
$HELP['editmenu_ret_btn']['title'] = '戻るボタン';
$HELP['editmenu_ret_btn']['body'] = '管理メニュー編集へ戻ります。';
$HELP['editmenu_top_image']['title'] = '管理メニュー画像';
$HELP['editmenu_top_image']['body'] = '管理メニュー上に表示する画像です。[Magic3ルート]からの相対パスで指定します。';

// ########## 置換文字列 ##########
$HELP['usercustom_list']['title'] = '置換文字列一覧';
$HELP['usercustom_list']['body'] = '置換文字列一覧です。置換文字列は、コンテンツテキストに埋め込み、コンテンツ表示時に自動変換される文字列です。';
$HELP['usercustom_detail']['title'] = '置換文字列詳細';
$HELP['usercustom_detail']['body'] = '置換文字列の情報を編集します。';
$HELP['usercustom_new_btn']['title'] = '新規ボタン';
$HELP['usercustom_new_btn']['body'] = '新規に置換文字列を追加します。';
$HELP['usercustom_edit_btn']['title'] = '編集ボタン';
$HELP['usercustom_edit_btn']['body'] = '選択されている置換文字列を編集します。<br />置換文字列を選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['usercustom_del_btn']['title'] = '削除ボタン';
$HELP['usercustom_del_btn']['body'] = '選択されている置換文字列を削除します。<br />置換文字列を選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['usercustom_ret_btn']['title'] = '戻るボタン';
$HELP['usercustom_ret_btn']['body'] = '置換文字列一覧へ戻ります。';
$HELP['usercustom_check']['title'] = '選択用チェックボックス';
$HELP['usercustom_check']['body'] = '編集や削除を行う項目を選択します。';

$HELP['usercustom_check2']['title'] = '選択用ラジオボタン';
$HELP['usercustom_check2']['body'] = '編集を行う項目を選択します。新規追加する場合は「新規追加」項目を選択します。';
$HELP['usercustom_key']['title'] = '置換キー文字列';
$HELP['usercustom_key']['body'] = 'コンテンツテキストに埋め込むキー文字列です。コンテンツ表示時に、この文字列が「置換内容」に変換されます。';
$HELP['usercustom_name']['title'] = '置換文字列名';
$HELP['usercustom_name']['body'] = '置換文字列の管理上の名前です。';
$HELP['usercustom_value']['title'] = '置換内容';
$HELP['usercustom_value']['body'] = 'コンテンツ表示時に、コンテンツ上の置換キーから変換される文字列です。';
?>

==> magic3_1.7.1_src.tar.gz: magic3/widgets/admin_main/include/help/index.php <==
<?php
/**
 * ヘルプリソースファイル
 * index.php
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2008 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: index.php 1240 2008-11-16 05:41:26Z fishbone $
 * @link       http://www.magic3.org
 */
// 直接アクセスの防止
defined('M3_SYSTEM') or die('Access error: Direct access denied.');

global $HELP;

// ########## ユーザ一覧 ##########
$HELP['userlist']['title'] = 'ユーザ一覧';
$HELP['userlist']['body'] = 'システムで一元管理するユーザの一覧です。';
$HELP['userlist_check']['title'] = '選択用チェックボックス';
$HELP['userlist_check']['body'] = '編集や削除を行う項目を選択します。';
$HELP['userlist_account']['title'] = 'ユーザアカウント';
$HELP['userlist_account']['body'] = 'ログイン時に使用するアカウントです。<br>メールアドレス形式のアカウントも使用できます。';
$HELP['userlist_pwd']['title'] = 'ユーザパスワード';
$HELP['userlist_pwd']['body'] = 'ログイン時に使用するパスワードです。';
$HELP['userlist_name']['title'] = '名前';
$HELP['userlist_name']['body'] = '画面上に表示されるユーザの名前です。';
$HELP['userlist_usertype']['title'] = 'ユーザ種別';
$HELP['userlist_usertype']['body'] = '管理者 - 管理機能にログインできます。<br>一般 - 管理機能以外の機能にログインできます。<br>仮登録 - 一般機能からユーザ登録を行い、まだログインしていないユーザです。一度ログインすると一般ユーザに変更されます。';
$HELP['userlist_admin']['title'] = '管理権限';
$HELP['userlist_admin']['body'] = '管理画面にアクセス可能かどうかの設定です。<br>チェックが入っているとアクセス可能です。';
$HELP['userlist_login']['title'] = 'ログイン可';
$HELP['userlist_login']['body'] = 'ログインを許可するかどうかの設定です。<br>チェックが入っているとログイン可能です。';
$HELP['userlist_new_btn']['title'] = '新規ボタン';
$HELP['userlist_new_btn']['body'] = '新規ユーザを追加します。';
$HELP['userlist_edit_btn']['title'] = '編集ボタン';
$HELP['userlist_edit_btn']['body'] = '選択されているユーザを編集します。<br>ユーザを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['userlist_del_btn']['title'] = '削除ボタン';
$HELP['userlist_del_btn']['body'] = '選択されているユーザを削除します。<br>ユーザを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['userlist_ret_btn']['title'] = '戻るボタン';
$HELP['userlist_ret_btn']['body'] = 'ユーザ一覧へ戻ります。';

// ########## 画面作成 ##########
$HELP['pagedef_page_id']['title'] = 'ページID';
$HELP['pagedef_page_id']['body'] = 'ページを定義するためのIDです。IDはURLに付加されます。非公開項目は管理権限のない一般ユーザには公開されないページです。';
$HELP['pagedef_page_sub_id']['title'] = 'ページサブID';
$HELP['pagedef_page_sub_id']['body'] = 'ページを定義するための補助IDです。IDはURLに付加されます。';
$HELP['pagedef_preview_url']['title'] = 'URL';
$HELP['pagedef_preview_url']['body'] = 'プレビューに表示しているページへのURLです。';
$HELP['pagedef_detail_btn']['title'] = '詳細ボタン';
$HELP['pagedef_detail_btn']['body'] = 'ページ定義の詳細を表示します。';
$HELP['pagedef_default_template']['title'] = 'デフォルトテンプレート';
$HELP['pagedef_default_template']['body'] = 'デフォルトで設定されるデザインテンプレートを指定します。';
$HELP['pagedef_change_template_btn']['title'] = 'テンプレート変更';
$HELP['pagedef_change_template_btn']['body'] = 'デフォルトのテンプレートを変更します。';
$HELP['pagedef_template_img']['title'] = 'テンプレート表示イメージ';
$HELP['pagedef_template_img']['body'] = 'テンプレートを設定した場合の画面の表示イメージです。';
$HELP['pagedef_widget']['title'] = 'ウィジェット';
$HELP['pagedef_widget']['body'] = 'レイアウトに配置可能なウィジェットです。シングルクリックで取得し、画面レイアウト領域に配置します。';
$HELP['pagedef_layout']['title'] = '画面レイアウト';
$HELP['pagedef_layout']['body'] = '(ウィジェットの配置)<br>テンプレートにウィジェットを配置し、画面を作成します。ウィジェット一覧からマウスドラッグでウィジェットを取り出します。レイアウト画面の任意のポジション位置にドロップするとウィジェットが配置できます。レイアウト画面からウィジェットを削除するには、削除するウィジェットの右上のクローズボックスをクリックします。一度ドロップしたウィジェットは、ドラッグドロップでページ上の移動が可能です。最大化ボタンまたはESCキーでレイアウト画面が最大化できます。最大化状態から元に戻るにはESCキーを押します。<br>(ウィジェットコンテキストメニュー)<br>ウィジェットをマウス右クリックするとコンテキストメニューが表示されます。ウィジェットの設定を行ったり、ウィジェットの削除を行います。「ページ共通」属性を設定したウィジェットは、ページに関わらず常に表示されます。(赤色表示)';
$HELP['pagedef_preview']['title'] = 'レイアウトとプレビューの切り替えボタン';
$HELP['pagedef_preview']['body'] = 'ウィジェットの配置を行うレイアウト画面と、実際に表示されるプレビュー画面を切り替えます。';
$HELP['pagedef_refresh']['title'] = '画面再表示';
$HELP['pagedef_refresh']['body'] = 'レイアウトまたはプレビュー画面を再表示します。';
$HELP['pagedef_preview_other']['title'] = '別画面でプレビュー';
$HELP['pagedef_preview_other']['body'] = '実際に表示される画面を別ウィンドウで表示します。';
$HELP['pagedef_position_block']['title'] = 'ポジションブロック名';
$HELP['pagedef_position_block']['body'] = 'デザインテンプレート内でのウィジェットの配置ブロックを指定します。';
$HELP['pagedef_position_index']['title'] = '表示順';
$HELP['pagedef_position_index']['body'] = 'ポジションブロック内でのウィジェットの表示順を指定します。';
$HELP['pagedef_widget_def_id']['title'] = '定義ID';
$HELP['pagedef_widget_def_id']['body'] = '個別のウィジェットの設定IDです。設定が必要な場合のみ設定可能になります。';
$HELP['pagedef_widget_visible']['title'] = 'ウィジェット表示制御';
$HELP['pagedef_widget_visible']['body'] = 'ウィジェットの表示、非表示を制御します。';
$HELP['pagedef_widget_common']['title'] = 'ページ共通属性';
$HELP['pagedef_widget_common']['body'] = '同ページIDで、サブページIDに関わらずウィジェットを表示するかどうかを指定します。';

// ########## テーブルデータ編集 ##########
$HELP['edittable_new_btn']['title'] = '新規ボタン';
$HELP['edittable_new_btn']['body'] = '新規レコードを追加します。';
$HELP['edittable_edit_btn']['title'] = '編集ボタン';
$HELP['edittable_edit_btn']['body'] = '選択されているレコードを編集します。<br>レコードを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['edittable_del_btn']['title'] = '削除ボタン';
$HELP['edittable_del_btn']['body'] = '選択されているレコードを削除します。<br>レコードを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['edittable_ret_btn']['title'] = '戻るボタン';
$HELP['edittable_ret_btn']['body'] = 'レコード一覧へ戻ります。';

// ########## 管理メニュー編集編集 ##########
$HELP['editmenu_config_others_btn']['title'] = 'その他ボタン';
$HELP['editmenu_config_others_btn']['body'] = 'その他の設定を行います。';
$HELP['editmenu_ret_btn']['title'] = '戻るボタン';
$HELP['editmenu_ret_btn']['body'] = '管理メニュー編集へ戻ります。';
$HELP['editmenu_top_image']['title'] = '管理メニュー画像';
$HELP['editmenu_top_image']['body'] = '管理メニュー上に表示する画像です。[Magic3ルート]からの相対パスで指定します。';

// ########## 置換文字列 ##########
$HELP['usercustom_list']['title'] = '置換文字列一覧';
$HELP['usercustom_list']['body'] = '置換文字列一覧です。置換文字列は、コンテンツテキストに埋め込み、コンテンツ表示時に自動変換される文字列です。';
$HELP['usercustom_detail']['title'] = '置換文字列詳細';
$HELP['usercustom_detail']['body'] = '置換文字列の情報を編集します。';
$HELP['usercustom_new_btn']['title'] = '新規ボタン';
$HELP['usercustom_new_btn']['body'] = '新規に置換文字列を追加します。';
$HELP['usercustom_edit_btn']['title'] = '編集ボタン';
$HELP['usercustom_edit_btn']['body'] = '選択されている置換文字列を編集します。<br />置換文字列を選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['usercustom_del_btn']['title'] = '削除ボタン';
$HELP['usercustom_del_btn']['body'] = '選択されている置換文字列を削除します。<br />置換文字列を選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['usercustom_ret_btn']['title'] = '戻るボタン';
$HELP['usercustom_ret_btn']['body'] = '置換文字列一覧へ戻ります。';
$HELP['usercustom_check']['title'] = '選択用チェックボックス';
$HELP['usercustom_check']['body'] = '編集や削除を行う項目を選択します。';

$HELP['usercustom_check2']['title'] = '選択用ラジオボタン';
$HELP['usercustom_check2']['body'] = '編集を行う項目を選択します。新規追加する場合は「新規追加」項目を選択します。';
$HELP['usercustom_key']['title'] = '置換キー文字列';
$HELP['usercustom_key']['body'] = 'コンテンツテキストに埋め込むキー文字列です。コンテンツ表示時に、この文字列が「置換内容」に変換されます。';
$HELP['usercustom_name']['title'] = '置換文字列名';
$HELP['usercustom_name']['body'] = '置換文字列の管理上の名前です。';
$HELP['usercustom_value']['title'] = '置換内容';
$HELP['usercustom_value']['body'] = 'コンテンツ表示時に、コンテンツ上の置換キーから変換される文字列です。';

// ########## ページ情報 ##########
$HELP['pageinfo']['title'] = 'ページ情報';
$HELP['pageinfo']['body'] = 'サイトのアクセス単位であるページについての情報を設定します。';
$HELP['pageinfo_list']['title'] = 'ページ情報一覧';
$HELP['pageinfo_list']['body'] = 'ページはアクセスポイントである「ページID」とサブパラメータの「ページサブID」のセットで一意に決まります。<br>ページサブIDはURLのクエリーパラメータ「sub=サブページID」で指定されるIDです。';
$HELP['pageinfo_detail']['title'] = 'ページ情報詳細';
$HELP['pageinfo_detail']['body'] = 'ページ情報を編集します。';

$HELP['pageinfo_check']['title'] = '選択用チェックボックス';
$HELP['pageinfo_check']['body'] = '編集を行う項目を選択します。';
$HELP['pageinfo_pageid']['title'] = 'ページID';
$HELP['pageinfo_pageid']['body'] = 'URLで実行されるスクリプトファイルがアクセスポイントであるページIDです。';
$HELP['pageinfo_subid']['title'] = 'ページサブID';
$HELP['pageinfo_subid']['body'] = 'URLのクエリーパラメータ「sub=サブページID」で指定するIDです。';
$HELP['pageinfo_name']['title'] = '名前';
$HELP['pageinfo_name']['body'] = '選択メニュー等で表示される名前です。';
$HELP['pageinfo_content']['title'] = 'コンテンツタイプ';
$HELP['pageinfo_content']['body'] = 'コンテンツタイプでページが指定された場合に表示されるページです。';
$HELP['pageinfo_public']['title'] = '公開';
$HELP['pageinfo_public']['body'] = '管理者以外のユーザがアクセス可能であるかどうかを示します。';
$HELP['pageinfo_default']['title'] = 'デフォルト';
$HELP['pageinfo_default']['body'] = 'デフォルトで選択されている項目は、ページサブIDが省略されたときに指定されるページサブIDです。';
$HELP['pageinfo_edit_btn']['title'] = '編集ボタン';
$HELP['pageinfo_edit_btn']['body'] = '選択されているページサブIDの情報を編集します。<br>選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['pageinfo_ret_btn']['title'] = '戻るボタン';
$HELP['pageinfo_ret_btn']['body'] = 'ページ情報一覧へ戻ります。';

// ########## ページID ##########
$HELP['pageid']['title'] = 'ページID';
$HELP['pageid']['body'] = 'ページID、ページサブIDの編集を行います';
$HELP['pageid_list']['title'] = 'ページID一覧';
$HELP['pageid_list']['body'] = 'ページIDの一覧です。ページIDとページサブIDを切り替えます。';
$HELP['pageid_detail']['title'] = 'ページID詳細';
$HELP['pageid_detail']['body'] = 'ページIDを編集します。';
$HELP['pageid_check']['title'] = '選択用チェックボックス';
$HELP['pageid_check']['body'] = '編集を行う項目を選択します。';
$HELP['pageid_id']['title'] = 'ページID';
$HELP['pageid_id']['body'] = 'ページIDまたはページサブIDを示します。';
$HELP['pageid_name']['title'] = '名前';
$HELP['pageid_name']['body'] = '選択メニュー等で表示される名前です。';
$HELP['pageid_desc']['title'] = '説明';
$HELP['pageid_desc']['body'] = '項目についての説明です。';
$HELP['pageid_path']['title'] = 'パス';
$HELP['pageid_path']['body'] = 'URLでのアクセスパスを示します。';
$HELP['pageid_priority']['title'] = '優先順';
$HELP['pageid_priority']['body'] = '項目の優先順を指定します。';
$HELP['pageid_active']['title'] = '有効';
$HELP['pageid_active']['body'] = 'ページIDが有効であるかどうかを指定します。無効のページIDはユーザからアクセスできません。';
$HELP['pageid_new_btn']['title'] = '新規ボタン';
$HELP['pageid_new_btn']['body'] = '新規ページIDを追加します。';
$HELP['pageid_edit_btn']['title'] = '編集ボタン';
$HELP['pageid_edit_btn']['body'] = '選択されているページIDを編集します。<br>選択するには、一覧の左端のチェックボックスにチェックを入れます。';
$HELP['pageid_ret_btn']['title'] = '戻るボタン';
$HELP['pageid_ret_btn']['body'] = 'ページID一覧へ戻ります。';
?>
